BOLD = 0x02
COLOR = 0x03
ITALIC = 0x1D
STRIKETHROUGH = 0x1e
RESET = 0x0f
UNDERLINE = 0x1f
MONOSPACE = 0x11

WHITE = 0
BLACK = 1
BLUE = 2
GREEN = 3
LIGHTRED = 4
DROWN = 5
PURPLE = 6
ORANGE = 7
YELLOW = 8
LIGHTGREEN = 9
CYAN = 10
LIGHTCYAN = 11
LIGHTBLUE = 12
PINK = 13
GREY = 14
LIGHTGRAY = 15
